/*
 * Copyright (c) 2009 Mysema Ltd.
 * All rights reserved.
 * 
 */
package com.mysema.commons.lang;

/**
 * 
 * 
 * @author tiwe
 * 
 */
public class Assert {

	/**
	 * Assert that the given String has valid text content; that is, it must not
	 * be <code>null</code> and must contain at least one non-whitespace
	 * character.
	 * @param str
	 * @return
	 */
	public static String hasText(String str) {
		int strLen = hasLength(str).length();
		for (int i = 0; i < strLen; i++) {
			if (!Character.isWhitespace(str.charAt(i))) return str;
		}
		throw new IllegalArgumentException("empty string");
	}

	/**
	 * Assert that an object is not <code>null</code> .
	 * @param <T>
	 * @param object
	 * @return
	 */
	public static <T> T notNull(T object) {
		return notNull(object, "null object");
	}

	/**
	 * Assert that an object is not <code>null</code> .
	 * 
	 * @param <T>
	 * @param object
	 * @param message
	 * @return
	 */
	public static <T> T notNull(T object, String message) {
		if (object == null) throw new IllegalArgumentException(message);
		return object;
	}

	/**
	 * Check that the given String is neither <code>null</code> nor of length 0.
	 * @param str
	 * @return
	 */
	public static String hasLength(String str) {
		if (str == null || str.length() == 0) 
			throw new IllegalArgumentException("empty string");
		return str;
	}

	/**
	 * Assert that an array has elements; that is, it must not be
	 * <code>null</code> and must have at least one element.
	 * @param <T>
	 * @param objects
	 * @return
	 */
	public static <T> T[] notEmpty(T[] objects) {
		if (objects == null || objects.length == 0) 
			throw new IllegalArgumentException("empty array");
		return objects;
	}

}