package com.mysema.commons.lang;

import java.net.URI;

/**
 * 
 * @author tiwe
 *
 */
public class URIUtil {

    private static final String VALID_SCHEME_CHARS = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789+.-";

    /**
     * 
     * @param url
     * @return
     */
    public static boolean isAbsoluteURL(String url) {
        // a null URL is not absolute, by our definition
        if (url == null)
            return false;

        // do a fast, simple check first
        int colonPos;
        if ((colonPos = url.indexOf(":")) == -1)
            return false;

        // if we DO have a colon, make sure that every character
        // leading up to it is a valid scheme character
        for (int i = 0; i < colonPos; i++)
            if (VALID_SCHEME_CHARS.indexOf(url.charAt(i)) == -1)
                return false;

        // if so, we've got an absolute url
        return true;
    }
    
    /**
     * 
     * @param base
     * @param url
     * @return
     */
    public static String resolve(String base, String url){
        if (isAbsoluteURL(url)) {
            return url;
            
        } else if (url.startsWith("?")){
            if (base.contains("?")){
                return base.substring(0, base.lastIndexOf('?')) + url;
            }else{
                return base + url;    
            }
            
        }else if (url.startsWith("#")){    
            if (base.contains("#")){
            	return base.substring(0, base.lastIndexOf('#')) + url;
            }else{
            	return base + url;
            }
            
        }else{
            return URI.create(base).resolve(url).toString();
        }     
    }
    
}
